Module halstead

Module halstead 

Halstead suite (operators, operands, volume, difficulty, effort).

Structs

HalsteadMaps
Per-space operator / operand occurrence maps used to compute the Halstead Stats struct. One map per distinct operator (kind_id) and one per distinct operand (text); merged across nested spaces.
Stats
The Halstead metric suite.

Enums

HalsteadType
Specifies the type of nodes accepted by the Halstead metric.