#[non_exhaustive]pub struct Stats { /* private fields */ }Expand description
The Mi metric.
Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn original(&self) -> f64
pub fn original(&self) -> f64
Returns the Mi metric calculated using the original formula.
Its value can be negative.
Sourcepub fn sei(&self) -> f64
pub fn sei(&self) -> f64
Returns the Mi metric calculated using the derivative formula
employed by the Software Engineering Insitute (SEI).
Its value can be negative.
Sourcepub fn visual_studio(&self) -> f64
pub fn visual_studio(&self) -> f64
Returns the Mi metric calculated using the derivative formula
employed by Microsoft Visual Studio.