#[non_exhaustive]pub struct Stats { /* private fields */ }Expand description
The Wmc metric.
This metric sums the cyclomatic complexities of all the methods defined in a class.
The Wmc (Weighted Methods per Class) is an object-oriented metric for classes.
Original paper and definition: https://www.researchgate.net/publication/3187649_Kemerer_CF_A_metric_suite_for_object_oriented_design_IEEE_Trans_Softw_Eng_206_476-493
Implementations
Sourceimpl Stats
impl Stats
Sourcepub fn interface_wmc(&self) -> u64
pub fn interface_wmc(&self) -> u64
Returns the Wmc metric value of the interfaces in a space.
Sourcepub fn class_wmc_sum(&self) -> u64
pub fn class_wmc_sum(&self) -> u64
Returns the sum of the Wmc metric values of the classes in a space.
Sourcepub fn interface_wmc_sum(&self) -> u64
pub fn interface_wmc_sum(&self) -> u64
Returns the sum of the Wmc metric values of the interfaces in a space.