pub struct AstCfg {
pub id: String,
pub language: String,
pub comment: bool,
pub span: bool,
}Expand description
Configuration options for retrieving the nodes of an AST.
Fields
id: StringThe id associated to a request for an AST
language: StringThe resolved source-language slug to echo in the response envelope (#654). The #540 canonical lowercase slug.
comment: boolIf true, nodes representing comments are ignored
span: boolIf true, the start and end positions of a node in a code
are considered