pub struct GroupBusFactor {
pub bus_factor: u32,
pub files: u32,
pub authors: u32,
pub key_author_ids: Option<Vec<String>>,
}Available on crate feature
vcs-git only.Expand description
Bus factor for one set of files (the repo, or one directory).
Fields
bus_factor: u32Developers whose combined departure orphans more than the coverage
threshold of the group’s files. 0 for an empty group.
files: u32Files considered (those with in-window authorship).
Distinct developers who author at least one file in the group.
SHA-256-hashed identities of the removed key developers, in
removal order; Some only under --emit-author-details.