pub fn score_diff_features(
size: JitSize,
diffusion: JitDiffusion,
) -> (f64, JitDiffContributions)Available on crate feature
vcs-git only.Expand description
Compute the partial (size + diffusion only) JIT score for an arbitrary
diff, reusing the same score math as a commit so the two terms are
computed by one code path. The history, experience, and purpose terms
are left at their zero defaults (no input), and their zero contributions
are discarded — only size and diffusion survive into the returned
JitDiffContributions.
The returned score is not comparable to a commit score; see
JitDiffReport.